@@ -2,7 +2,10 @@
         pkgs <- c("methods", "stashR")
 
         for(pkg in pkgs) {
-                if(!require(pkg, quietly = TRUE, character.only = TRUE))
+                status <- suppressMessages({
+                        require(pkg, quietly = TRUE, character.only = TRUE)
+                })
+                if(!status)
                         stop(gettextf("'%s' package is required", pkg))
         }
         stashR::stashROption("quietDownload", TRUE)
